import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea } from '@tarojs/components'
import Taro, { getCurrentInstance } from '@tarojs/taro'
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {
    draw_status: 0,
    draw_data: {},
    draw_infos: [],
    que_cnt: 0,
    default_img: '',
    interval: null

  }

  componentWillMount () {
    this.getDrawTaskStatus()
  }
  getDrawTaskStatus () {
    let routers = this.$instance.router.params
    api.getDrawTaskStatus({ task_id: routers.task_id }).then(res => {
      //定时器不要轻易改，避免造成服务器攻击
      if (res.code == 200) {
        let draw_infos = res.data.draw_infos
        if (res.data.draw_status != 2) {
          let params = {}
          params['img'] = res.data.default_img
          draw_infos.push(params)
        }
        console.log(draw_infos, 'draw_infos');
        if (res.data.draw_status != 2 && res.data.que_cnt > 1) {
          this.state.interval = setInterval(() => {
            this.getDrawTaskStatus()
          }, 1000 * 30)
        } else if (res.data.draw_status != 2 && res.data.que_cnt <= 1) {
          clearInterval(this.state.interval)
          this.state.interval = setInterval(() => {
            this.getDrawTaskStatus()
          }, 1000 * 5)
        } else {
          clearInterval(this.state.interval)
        }
        this.setState({
          draw_status: res.data.draw_status,
          draw_data: res.data.draw_data,
          que_cnt: res.data.que_cnt,
          draw_infos: draw_infos
        })
      }
    })
  }
  download () {
    // Taro.downloadFile({
    //   url: this.state.draw_infos[0].img, //仅为示例，并非真实的资源
    //   success: function (res) {
    //     // 只要服务器有响应数据，就会把响应内容写入文件并进入 success 回调，业务需要自行判断是否下载到了想要的内容
    //     if (res.statusCode === 200) {
    //       Taro.playVoice({
    //         filePath: res.tempFilePath
    //       })
    //     }
    //   }
    // })
    this.downImg()
  }
  // 鉴权操作 判断是否有保存到相册的权限
  // 有就直接下载 没有就弹窗提示给权限
  downImg () {
    Taro.getSetting({
      success: res => {
        if (!res.authSetting['scope.writePhotosAlbum']) {
          Taro.authorize({
            scope: 'scope.writePhotosAlbum',
            success: () => {
              this.doSaveImg()
            },
            fail: () => {
              this.openConfirm()
            }
          })
        } else {
          this.doSaveImg()
        }
      }
    })
  }
  // 生成临时路径 保存图片到手机
  doSaveImg () {
    Taro.downloadFile({
      url: this.state.draw_infos[0].img,
      success: res => {
        Taro.saveImageToPhotosAlbum({
          filePath: res.tempFilePath,
          success: () => {
            Taro.showToast({ title: '已保存到相册', icon: 'success' })
          },
          fail: () => {
            Taro.showToast({ title: '保存失败', icon: 'none' })
          }
        })
      }
    })
  }
  // 权限弹窗
  openConfirm () {
    Taro.showModal({
      content: '检测到您没有打开小程序相册权限，是否取设置打开？',
      showCancel: true,
      success: res => {
        if (res.confirm) {
          // 打开权限
          Taro.openSetting({
            success: res => {
              this.doSaveImg()
            }
          })
        }
      }
    })
  }


  componentDidMount () { }
  //页面销毁之前调用
  componentWillUnmount () {
    //避免服务器攻击
    clearInterval(this.state.interval)
  }


  render () {
    return (
      <View className='mine'>
        <Swiper
          className='banner'
          indicatorColor='#121D34'
          indicatorActiveColor='#0F84EC'
          circular
          adjustHeight='first'
          indicatorDots
          autoplay>
          {
            this.state.draw_infos.map((item, index) => (
              <SwiperItem key={index}>
                <View className='banner-info'>
                  <Image className='banner-image' mode='aspectFit' src={item.img}></Image>
                </View>
              </SwiperItem>
            ))
          }
          {
            this.state.draw_status != 2 &&
            <View className='banner-tips'>
              预计等待{this.state.que_cnt + 1}分钟...
            </View>
          }
          {/* <SwiperItem>
            <View className='demo-text-2'><Image ></Image></View>
          </SwiperItem>
          <SwiperItem>
            <View className='demo-text-3'><Image ></Image></View>
          </SwiperItem> */}
        </Swiper>
        <View className='content'>
          <View className='draw-title'>绘画描述</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.draw_data.prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              disabled
            />
            
          </View>
          <View className='draw-content'>
            <View className='draw-info'>
              <View className='info-title'>模型</View>
              <View className='info-text'>{this.state.draw_data.model_name} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>风格</View>
              <View className='info-text'>{ } </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>图片尺寸</View>
              <View className='info-text'>{this.state.draw_data.img_size} </View>
            </View>
            {/* <View className='draw-info'>
              <View className='info-title'>图片质量</View>
              <View className='info-text'>{} </View>
            </View> */}
          </View>
          <View className='draw-title'>绘画不要的元素</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.draw_data.negative_prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              disabled
            />
          </View>
        </View>
        <View className='func'>
          <View className='func-list'>
            {/* <View className='func-info'>
              <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952380367.png'></Image>
              <View>发布</View>
            </View> */}
            <View className='func-info'>
              <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952396973.png'></Image>
              <View>分享</View>
            </View>
            <View className='func-info' onClick={e => (this.download())}>
              <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952411029.png'></Image>
              <View>下载</View>
            </View>
          </View>
        </View>
      </View>
    )
  }
}
