import { Component } from 'react'
import { View, Text, Button, Image, scrollView, Input, Textarea, Slider } from '@tarojs/components'
import Taro, { getCurrentInstance } from '@tarojs/taro'
import * as api from '../../service/index'

import './index.less'

export default class Mine extends Component {

  state = {
    models: [],//模板
    imgSize: [],//图片尺寸
    sampling: [],//采样方式
    samplingIndex: 0,//当前选择的采样方式
    loraIndex: 0,//当前选择的lora
    sizeIndex: 0,//当前选择的尺寸
    isOpen: false,
    value: '',//绘画描述
    negativeValue: '',//不要的元素
    modelIndex: 0,//当前选择的模型
    sliderNum: 7,//色彩丰富度
    drawNum: 1,//图片数量
  }

  componentDidShow () {
    this.getDrawIndex()
  }

  componentDidMount () { }

  getMyDraw () {
    api.getMyDraw({ page_size: 100 })
  }
  getDrawIndex () {
    api.getDrawIndex().then(res => {
      if (res.code == 200) {
        this.setState({
          models: res.data.models,
          imgSize: res.data.img_size,
          sampling: res.data.Sampler
        })
      }
    })
  }
  getRadomPrompt () {
    api.getRadomPrompt().then(res => {
      if (res.code == 200) {
        this.setState({
          value: res.data.prompt,
          negativeValue: res.data.negative_prompt
        })
        document.getElementById('textarea-num').innerHTML = res.data.prompt.length + "/1000";
        document.getElementById('negative_prompt').innerHTML = res.data.negative_prompt.length + "/1000";
      }
    })
  }
  onInput (e) {
    console.log(e, 'e')
    var num = e.detail.cursor;
    document.getElementById('textarea-num').innerHTML = num + "/1000";
  }
  onBlur (e) {
    this.setState({
      value: e.detail.value
    })
    console.log(e, 'onBlur');
  }
  onInputNegative (e) {
    console.log(e, 'e');
    var num = e.detail.cursor;
    document.getElementById('negative_prompt').innerHTML = num + "/1000";
  }
  onBlurNegative(e){
    this.setState({
      negativeValue: e.detail.value
    })
  }
  changeOpen () {
    this.setState({
      isOpen: !this.state.isOpen
    })
  }
  selectModel (item, index) {
    this.setState({
      modelIndex: index,
      loraIndex: 0
    })
  }
  subNum () {
    if (this.state.drawNum <= 1) return
    this.setState({
      drawNum: this.state.drawNum - 1
    })
  }
  addNum () {
    if (this.state.drawNum >= 4) return
    this.setState({
      drawNum: this.state.drawNum + 1
    })
  }
  changeMeasurement (item, index) {
    this.setState({
      sizeIndex: index
    })
  }
  changeSampling (item, index) {
    this.setState({
      samplingIndex: index
    })
  }
  changeLora (item, index) {
    this.setState({
      loraIndex: index
    })
  }
  //生成图片
  generatePictures () {
    console.log('生成图片');
    console.log();
    setTimeout(() => {
      if (this.state.value.length == 0) {
        Taro.showToast({
          title: `请填写绘画描述`,
          icon: 'error',
        });
        return
      }
      let pramas = {
        model_name: this.state.models[this.state.modelIndex].model_name,
        file_name: this.state.models[this.state.modelIndex].lora_infos.length > 0 ? this.state.models[this.state.modelIndex].lora_infos[this.state.loraIndex].file_name : '',
        img_size: this.state.imgSize[this.state.sizeIndex].name,
        img_cnt: this.state.drawNum,
        cfg_scale: this.state.sliderNum,
        sampler: this.state.sampling[this.state.samplingIndex],
        prompt: this.state.value,
        negative_prompt: this.state.negativeValue
      }
      api.drawTxt2img(pramas).then(res => {
        if (res.code == 200) {
          Taro.navigateTo({
            url: `/pages/darwDetail/index?task_id=${res.data.task_id}`
          })
        }
      })
    },1000)
  }
  toChat (e) {
  }

  render () {
    return (
      <View className='mine'>
        {/* <View className='banner'>
          <Image className='banner-image' src=''></Image>
        </View> */}
        <View className='draw-content'>
          <View className='draw-brack'>
            <View className='draw-tab'>
              <View className='tab-text' style={'background: #0F84EC;color: #FFFFFF;'}>AI绘画</View>
              <View className='tab-text'>人物头像</View>
              <View className='tab-text'>风景头像</View>
            </View>
          </View>
          <View className='draw-title'>绘画描述</View>
          <View className='draw-text'>
            <View className='recommend'>
              <Image className='recommend-img' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678934357612.png'></Image>
              <View className='recommend-text' onClick={e => (this.getRadomPrompt())}>使用推荐词</View>
            </View>
            <Textarea
              value={this.state.value}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              onInput={e => (this.onInput(e))}
              onBlur={e => (this.onBlur(e))}

              maxlength='1000' />
            <View className='textarea-num' id='textarea-num'>{this.state.value.length}/1000</View>
          </View>
          <View className='draw-title'>选择模型</View>
          <View className='model-list'>
            {
              !this.state.isOpen ?
                this.state.models.slice(0, 6).map((item, index) => (
                  <View className='model-info'
                    style={this.state.modelIndex == index ? `border: 2px solid #0F84EC; background:url(${item.img});background-size: 100% 100%;` : `background:url(${item.img});background-size: 100% 100%;`}
                    key={index}
                    onClick={e => (this.selectModel(item, index))}>
                    <View className='model-info-bottom'>
                      {item.name}
                    </View>
                  </View>
                )) :
                this.state.models.map((item, index) => (
                  <View className='model-info'
                    style={this.state.modelIndex == index ? `border: 2px solid #0F84EC; background:url(${item.img});background-size: 100% 100%;` : `background:url(${item.img});background-size: 100% 100%;`}
                    key={index}
                    onClick={e => (this.selectModel(item, index))}>
                    <View className='model-info-bottom'>
                      {item.name}
                    </View>
                  </View>
                ))
            }
          </View>
          <View className='isOpen'>
            <View className='open-content' onClick={e => (this.changeOpen())}>
              <View className='open-title'>{!this.state.isOpen ? '展开' : '收起'}</View>
              <Image className='open-img' src={!this.state.isOpen ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678935050487.png' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678935114571.png'}></Image>
            </View>
          </View>
          {
            this.state.models[this.state.modelIndex] &&
            this.state.models[this.state.modelIndex].lora_infos.length > 0 &&
            <View>
              <View className='draw-title'>风格</View>
              <View className='model-style-list'>
                {
                  this.state.models[this.state.modelIndex].lora_infos.map((item, index) => (
                    <View className='model-style-info' key={index} style={this.state.loraIndex == index ? `border: 2px solid #0F84EC;background:url(${item.img});background-size: 100% 100%;` : `background:url(${item.img});background-size: 100% 100%;`} onClick={e => (this.changeLora(item, index))}>
                      <View className='model-style-info-name'>{item.name}</View>
                    </View>
                  ))
                }

              </View>
            </View>
          }
          <View className='draw-title'>色彩丰富度</View>
          <View className='components-page'>
            <Slider style={'margin: 10px 0;'} showValue step={1} max={15} min={1} activeColor='#0F84EC' value={this.state.sliderNum} />
          </View>
          <View className='draw-title'>图片尺寸</View>
          <View className='measurement-list'>
            {
              this.state.imgSize.map((item, index) => (
                <View className='measurement-info' style={this.state.sizeIndex == index ? 'border: 2px solid #0F84EC;' : ''} key={index} onClick={e => (this.changeMeasurement(item, index))}>
                  <Image className='measurement-img' src=''></Image>
                  <View className='measurement-title'>{item.name}</View>
                </View>
              ))
            }
          </View>
          <View className='draw-title'>生成数量</View>
          <View className='draw-num'>
            <View className='subtract' onClick={e => (this.subNum())}>-</View>
            <View className='num'>{this.state.drawNum}</View>
            <View className='add' onClick={e => (this.addNum())}>+</View>
          </View>
          <View className='draw-title'>图片质量</View>
          <View className='draw-mass'>
            <View className='mass-same'>一般</View>
            <View className='mass-high'>高清</View>
          </View>
          <View className='draw-title'>采样方式</View>
          <View className='draw-sampling'>
            {
              this.state.sampling.map((item, index) => (
                <View className='sampling-same' style={this.state.samplingIndex == index ? 'border: 2px solid #0F84EC;' : ''} key={index} onClick={e => (this.changeSampling(item, index))}>{item}</View>
              ))
            }
          </View>
          <View className='draw-title'>绘画不要的元素</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.negativeValue}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              onInput={e => (this.onInputNegative(e))}
              onBlur={e => (this.onBlurNegative(e))}
              maxlength='1000' />
            <View className='textarea-num' id='negative_prompt'>{this.state.negativeValue.length}/1000</View>
          </View>
        </View>
        <View className='generate-pictures' onClick={e => (this.generatePictures(e))} >
          生成图片（消耗2积分）
        </View>
      </View>
    )
  }
}
